//
//  GameParametersMenuView.swift
//  ArkitDoushiQi
//
//  Created by Johan LACHENAL, Louis DUFOUR on 24/05/2024.
//

import SwiftUI
import PhotosUI

struct GameParametersMenuView: View, KeyboardReadable {
    @State private var selectedGameType: GameType = .PvP
    @State private var selectedAIOption: AI = .RandomAction
    @State private var selectedRulesOption: Rules = .Regular
    @State private var keyboardHeight: CGFloat = 0

    var body: some View {
        NavigationStack {
            VStack(alignment: .leading, spacing: 15) {
                Text(LocalizedStringKey("Paramètres de partie"))
                    .bold()
                    .font(.largeTitle)
                    .padding(.top, 20)

                PickerComponent(title: LocalizedStringKey("Sélectionne le type de partie :"),
                                selectedOption: $selectedGameType,
                                options: GameType.allCases)
                    .padding(.horizontal)

                PickerComponent(title: LocalizedStringKey("Sélectionne les règles :"),
                                selectedOption: $selectedRulesOption,
                                options: Rules.allCases)
                    .padding(.horizontal)

                if selectedGameType == .PvAI {
                    PickerComponent(title: LocalizedStringKey("Sélectionne une IA :"),
                                    selectedOption: $selectedAIOption,
                                    options: AI.allCases)
                        .padding(.horizontal)
                }

                ProfileEdit(color: Color(.red), profileWidth: 80, profileHeight: 80, defaultImage: Image("profil"), imageTextChange: LocalizedStringKey("changer l'avatar du joueur 1"), playerNameKey: LocalizedStringKey("Nom du Joueur 1"))

                if selectedGameType == .PvP {
                    ProfileEdit(color: Color(.blue), profileWidth: 80, profileHeight: 80, defaultImage: Image("profil"), imageTextChange: LocalizedStringKey("changer l'avatar du joueur 2"), playerNameKey: LocalizedStringKey("Nom du Joueur 2"))
                }

                Spacer()

                ButtonComponent(title: LocalizedStringKey("Lancer la partie")) {
                    GameView()
                }
                .padding(.horizontal, 32)
                .padding(.bottom, 20)
            }
            .onReceive(keyboardPublisher) { height in
                withAnimation {
                    self.keyboardHeight = height
                }
            }
            .padding(.horizontal, 20)
            .padding(.bottom, keyboardHeight) // Ajouter le padding en bas pour éviter le clavier
            .padding(.top, 20) // Ajuster le padding en haut si nécessaire
        }
    }
}

struct GameParametersMenuView_Previews: PreviewProvider {
    static var previews: some View {
        GameParametersMenuView()
    }
}
